.tv-samsung-ws-container{height:100%;display:flex;justify-content:center}.tv-samsung-ws-container .controls{max-width:500px;height:calc(100% - .15em);display:flex;align-items:center;justify-content:center;flex-direction:column;padding:0 1em;border:1px solid #ddd;border-radius:2em;box-shadow:0 2px 9px 2px #bbb}.tv-samsung-ws-container .controls .power{color:red}.tv-samsung-ws-container .controls button{margin:.5em 0}.tv-samsung-ws-container .rows{flex-direction:column}.tv-samsung-ws-container .rows * button{width:100%}.tv-samsung-ws-container .section{width:100%;display:flex;margin:0 0 1.5em 0;padding:0 0 1.5em 0;border-bottom:1px solid #ddd}.tv-samsung-ws-container .directions{flex-direction:column}.tv-samsung-ws-container .directions * button{width:5em;height:4em}.tv-samsung-ws-container .volume,.tv-samsung-ws-container .channel{text-align:center}.tv-samsung-ws-container .colors{text-align:center}.tv-samsung-ws-container .colors .color{width:3em;height:3em;padding:0;border-radius:2em}.tv-samsung-ws-container .colors .color.red{background:red}.tv-samsung-ws-container .colors .color.green{background:green}.tv-samsung-ws-container .colors .color.yellow{background:#ff0}.tv-samsung-ws-container .colors .color.blue{background:blue}
